<?php

namespace App\Controllers;

use App\Services\ModuleRegistry;
use CodeIgniter\Controller;

class BuilderController extends Controller
{
    public function index()
    {
        $modules = ModuleRegistry::loadAll();
        return view('builder/index', ['modules' => $modules]);
    }

    public function loadModule()
    {
        $class = $this->request->getGet('class');
        $fqcn = "App\\Modules\\$class";
        $file = APPPATH . 'Modules/' . $class . '.php';

        if (file_exists($file)) {
            require_once $file;
        }

        if (!class_exists($fqcn)) {
            return "❌ Module not found: $fqcn";
        }

        $mod = new $fqcn();
        return $mod->render();
    }

    public function loadSettings()
    {
        $class = $this->request->getGet('class');
        $fqcn = "App\\Modules\\$class";
        $file = APPPATH . 'Modules/' . $class . '.php';

        if (file_exists($file)) {
            require_once $file;
        }

        if (!class_exists($fqcn)) {
            return "❌ Settings not found for module: $fqcn";
        }

        $mod = new $fqcn();
        return $mod->renderSettings();
    }

    public function updateModule()
    {
        $payload = json_decode($this->request->getBody(), true);

        $class = $payload['class'] ?? '';
        $moduleId = $payload['moduleId'] ?? '';
        $settings = $payload['settings'] ?? [];

        $fqcn = "App\\Modules\\$class";
        $file = APPPATH . 'Modules/' . $class . '.php';

        if (!file_exists($file) || !class_exists($fqcn)) {
            if (file_exists($file)) require_once $file;
            if (!class_exists($fqcn)) {
                return "❌ Failed to update module: $fqcn";
            }
        }

        $mod = new $fqcn($settings);
        return $mod->render();
    }

    public function saveForm()
    {
        if (!$this->request->is('post')) {
            return $this->response->setJSON([
                'status' => 'error',
                'message' => 'Only POST requests are allowed.'
            ]);
        }

        $form_name = $this->request->getPost('form_name');
        $form_description = $this->request->getPost('form_description');
        $form_structure = $this->request->getPost('form_structure');

        try {
            $db = \Config\Database::connect();
            $builder = $db->table('forms');

            $builder->insert([
                'form_name' => $form_name,
                'form_description' => $form_description,
                'form_structure' => $form_structure,
            ]);

            return $this->response->setJSON([
                'status' => 'success',
                'message' => 'Form saved successfully.',
                'form_id' => $db->insertID()
            ]);
        } catch (\Throwable $e) {
            log_message('error', 'Form save failed: ' . $e->getMessage());
            return $this->response->setJSON([
                'status' => 'error',
                'message' => 'Database error: ' . $e->getMessage()
            ]);
        }
    }

    public function viewForm($slug)
    {
        $db = \Config\Database::connect();
        $form = $db->table('forms')->where('form_description', $slug)->get()->getRow();

        if (!$form) {
            return view('errors/html/error_404', ['message' => "Form not found for slug: $slug"]);
        }

        $modulesData = json_decode($form->form_structure, true);

        return view('builder/view_form', [
            'formName' => $form->form_name,
            'modules' => $modulesData,
        ]);
    }
}
