<?php
namespace App\Modules;

class TitlePage
{
    protected $settings;
    protected $instanceId;

    public function __construct($settings = [])
    {
        $this->instanceId = uniqid('titlePage_');

        $defaults = [
            'buttonName'      => 'Title Page',
            'buttonPosition'  => 1,
            'title'           => 'Title',
            'subtitle'        => 'Subtitle',
            'subsubtitle'     => '',
            'author'          => 'By Author Name',
            'topLogo'         => 'https://iihmrbangalore.edu.in/wp-content/uploads/2022/10/placeholder-round.png',
            'topLogoWidth'    => 230,
        ];

        $this->settings = array_merge($defaults, $settings);
    }

    public function getButtonName()
    {
        return $this->settings['buttonName'];
    }

    public function getButtonPosition()
    {
        return $this->settings['buttonPosition'];
    }

    public function renderPreviewButton()
    {
        return '<button class="list-group-item list-group-item-action" data-module="TitlePage">'
             . htmlspecialchars($this->getButtonName())
             . '</button>';
    }

    public function render()
    {
        ob_start();

        // ✅ Load CSS only once even if multiple instances exist
        static $cssIncluded = false;
        if (!$cssIncluded) {
            echo '<link rel="stylesheet" href="/assets/css/modules/title-page.css?v=' . time() . '">' . PHP_EOL;
            echo '<link href="https://fonts.googleapis.com/css2?family=Cinzel:wght@600&family=Merriweather:ital,wght@1,700&family=Playfair+Display:ital,wght@1,700&display=swap" rel="stylesheet">' . PHP_EOL;
            $cssIncluded = true;
        }
        ?>

        <div 
            class="module-preview title-page-module aspect-ratio-box"
            data-module="TitlePage"
            data-module-id="<?= htmlspecialchars($this->instanceId); ?>"
        >
            <div class="title-page-inner">
                <div class="logo-wrapper">
                    <img 
                        src="<?= htmlspecialchars($this->settings['topLogo']); ?>" 
                        alt="Top Logo" 
                        class="title-logo"
                        style="width: <?= (int) $this->settings['topLogoWidth']; ?>px"
                        loading="eager"
                    >
                </div>

                <hr class="feather-line">
                <div class="title-heading"><?= htmlspecialchars($this->settings['title']); ?></div>
                <div class="subtitle-heading"><?= htmlspecialchars($this->settings['subtitle']); ?></div>

                <?php if (!empty($this->settings['subsubtitle'])): ?>
                    <div class="subsubtitle-heading"><?= htmlspecialchars($this->settings['subsubtitle']); ?></div>
                <?php endif; ?>

                <hr class="feather-line">
                <div class="author-line"><?= htmlspecialchars($this->settings['author']); ?></div>
            </div>

            <!-- 🟡 Embedded settings for saving -->
            <script type="application/json"><?= json_encode($this->settings); ?></script>
        </div>
        <?php return ob_get_clean();
    }

    public function renderSettings()
    {
        ob_start(); ?>
        <div class="settings-group" data-settings-for="TitlePage">
            <div class="mb-3">
                <label class="form-label">Title</label>
                <input type="text" class="form-control" data-setting="title" value="<?= htmlspecialchars($this->settings['title']); ?>">
            </div>
            <div class="mb-3">
                <label class="form-label">Subtitle</label>
                <input type="text" class="form-control" data-setting="subtitle" value="<?= htmlspecialchars($this->settings['subtitle']); ?>">
            </div>
            <div class="mb-3">
                <label class="form-label">Sub-subtitle</label>
                <input type="text" class="form-control" data-setting="subsubtitle" value="<?= htmlspecialchars($this->settings['subsubtitle']); ?>">
            </div>
            <div class="mb-3">
                <label class="form-label">Author</label>
                <input type="text" class="form-control" data-setting="author" value="<?= htmlspecialchars($this->settings['author']); ?>">
            </div>
        </div>
        <?php return ob_get_clean();
    }
}
