<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8" />
  <title>AppMaker Builder</title>
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
  <link rel="stylesheet" href="/assets/css/builder.css?v=<?= time(); ?>">
  <link rel="stylesheet" href="/assets/css/modules.css?v=<?= time(); ?>">
  
</head>
<body>

<!-- Top Navbar -->
<nav class="navbar navbar-expand-lg navbar-light bg-light border-bottom shadow-sm">
  <div class="container-fluid">
    <a class="navbar-brand" href="#">AppMaker</a>
    <form class="d-flex ms-auto">
      <input class="form-control me-2" type="text" placeholder="App Name" id="form-name" />
      <input class="form-control me-2" type="text" placeholder="App Slug" id="form-slug" />
      <button class="btn btn-primary" type="button" id="save-button">Save Application</button>
    </form>
  </div>
</nav>

<!-- AppMaker Builder Layout -->
<div class="appmaker-container">

  <!-- LEFT SIDEBAR -->
  <div class="sidebar-left">
    <h5 class="mb-3">Modules</h5>
    <div class="list-group">
      <?php if (!empty($modules)): ?>
        <?php foreach ($modules as $mod): ?>
          <?= $mod->renderPreviewButton(); ?>
        <?php endforeach; ?>
      <?php else: ?>
        <p class="text-muted">⚠️ No modules found.</p>
      <?php endif; ?>
    </div>
  </div>

  <!-- PREVIEW CANVAS -->
  <div class="preview-canvas">
    <h4 class="mb-3">Your App Preview</h4>
    <hr>
    <div id="preview-canvas" class="mb-5">
      <!-- Modules appear here -->
    </div>
  </div>

  <!-- RIGHT SIDEBAR -->
  <div class="sidebar-right">
    <div id="settings-panel">
      <p class="text-muted">Select a module to edit settings below:</p>
    </div>
  </div>
</div>

<!-- Bootstrap JS -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

<!-- Load jQuery First -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>

<!-- Link to New Form Save JavaScript -->
<script src="/js/form-save.js?v=<?= time(); ?>"></script>

<!-- Module Load -->
<script>
  document.querySelectorAll('[data-module]').forEach(btn => {
    btn.classList.add('list-group-item', 'list-group-item-action');

    btn.addEventListener('click', () => {
      const mod = btn.dataset.module;

      fetch(`/index.php/builder/loadModule?class=${mod}`)
        .then(res => {
          if (!res.ok) throw new Error(`Server error ${res.status}`);
          return res.text();
        })
        .then(html => {
          const lc = html.trim().toLowerCase();
          if (lc.includes('not found') || lc.includes('fatal error')) {
            alert(`❌ Could not load "${mod}"`);
            return;
          }
          document.getElementById('preview-canvas').insertAdjacentHTML('beforeend', html);
        })
        .catch(err => {
          alert("⚠️ Module load failed.");
          console.error("Load error:", err);
        });

      fetch(`/index.php/builder/loadSettings?class=${mod}`)
        .then(res => {
          if (!res.ok) throw new Error(`Settings load error ${res.status}`);
          return res.text();
        })
        .then(html => {
          document.getElementById('settings-panel').innerHTML = html;
        })
        .catch(err => {
          alert("⚠️ Failed to load settings.");
          console.error("Settings error:", err);
        });
    });
  });
</script>

<!-- Live Update Logic -->
<script>
  document.addEventListener('input', function (e) {
    if (e.target.dataset.setting) {
      const settingKey = e.target.dataset.setting;
      const newValue = e.target.value;

      const moduleWrapper = document.querySelector('[data-module-id]');
      const moduleId = moduleWrapper?.dataset.moduleId;
      const moduleType = moduleWrapper?.dataset.module;

      if (!moduleId || !moduleType) return;

      const updatedSettings = {};
      document.querySelectorAll('[data-setting]').forEach(input => {
        updatedSettings[input.dataset.setting] = input.value;
      });

      fetch('/index.php/builder/updateModule', {
        method: 'POST',
        headers: { 'Content-Type': 'application/json' },
        body: JSON.stringify({
          class: moduleType,
          moduleId: moduleId,
          settings: updatedSettings
        })
      })
      .then(res => res.text())
      .then(html => {
        const wrapper = document.querySelector(`[data-module-id="${moduleId}"]`);
        if (wrapper) wrapper.outerHTML = html;
      })
      .catch(err => {
        alert("⚠️ Live update failed");
        console.error(err);
      });
    }
  });
</script>



</body>
</html>
