console.log("🚀 NEW form-save.js running — version 4");

document.addEventListener("DOMContentLoaded", function () {
  const saveButton = document.getElementById("save-button");
  if (!saveButton) {
    console.error("❌ Save button not found");
    return;
  }

  console.log("✅ Save button found — binding click event");

  saveButton.addEventListener("click", function () {
    console.log("🟢 Save Application button clicked");
    saveForm();
  });
});

function saveForm() {
  const formName = document.getElementById("form-name")?.value || "";
  const formSlug = document.getElementById("form-slug")?.value || "";

  // 🔥 Grab all modules from the preview area
  const moduleEls = document.querySelectorAll(".module-preview");

  const modules = Array.from(moduleEls).map(el => {
    const moduleName = el.getAttribute("data-module");
    const settingsScript = el.querySelector("script[type='application/json']");
    let settings = {};

    if (settingsScript) {
      try {
        settings = JSON.parse(settingsScript.textContent);
      } catch (err) {
        console.warn("⚠️ Invalid settings JSON in module:", moduleName, err);
      }
    }

    return {
      module_name: moduleName,
      settings: settings
    };
  });

  const payload = {
    form_name: formName,
    form_description: formSlug,
    form_structure: JSON.stringify(modules)
  };

  console.log("📤 Form Data being sent:", payload);

  $.ajax({
    url: "/index.php/builder/saveForm",
    method: "POST",
    data: payload,
    success: function (response) {
      console.log("✅ Save successful:", response);
      alert("Form saved successfully!");
    },
    error: function (error) {
      console.error("❌ Error during save:", error);
      alert("Error saving form. Check console.");
    }
  });
}
