// Existing code for input changes
document.addEventListener('input', function (e) {
  const input = e.target.closest('[data-setting]');
  if (!input) return;

  const settingName = input.getAttribute('data-setting');
  const instanceId = document.querySelector('.module-preview[data-module-id]')?.getAttribute('data-module-id');
  const moduleName = document.querySelector('.module-preview[data-module]')?.getAttribute('data-module');
  if (!instanceId || !moduleName) return;

  const value = input.value;

  // Handle updating settings as before
  updateModuleSettings(instanceId, {
    [settingName]: value
  });
});

// Added click event listener for module selection
document.addEventListener('click', function (e) {
  const moduleWrapper = e.target.closest('.module-preview');
  if (!moduleWrapper) return;

  const moduleId = moduleWrapper.dataset.moduleId;

  // Deselect previous
  document.querySelectorAll('.module-preview').forEach(mod => {
    mod.classList.remove('focused');
  });

  // Select clicked
  moduleWrapper.classList.add('focused');

  // Optional: Load settings for this module here if needed
});

// Function to save the form structure and modules
function saveForm() {
  const formStructure = {
    form_name: document.getElementById('form-name').value,  // Assume you have an input for the form name
    form_description: document.getElementById('form-description').value,  // Same for description
    modules: []  // We'll collect module data here
  };

  // Collect module data (fields, labels, settings, etc.)
  document.querySelectorAll('.module-preview').forEach(module => {
    const moduleData = {
      module_name: module.dataset.moduleName,  // Example data attribute for module type
      label: module.querySelector('label').textContent,  // Example: Get label text
      settings: {}  // You can add more dynamic settings as needed
    };
    formStructure.modules.push(moduleData);  // Add this module to the form structure
  });

  // Serialize form data
  const formData = {
    form_name: formStructure.form_name,
    form_description: formStructure.form_description,
    form_structure: JSON.stringify(formStructure.modules)  // Serialize modules into JSON
  };

  // Send form data to the backend via AJAX
  $.ajax({
    url: 'save_form.php',  // Backend PHP script for saving
    method: 'POST',
    data: formData,
    success: function(response) {
      console.log('Form saved successfully!', response);
      // You can redirect or show a success message here
    },
    error: function(error) {
      console.log('Error saving form:', error);
    }
  });
}
